==> dice-0.1.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-H60z5Pag986CnHmdNz2OU6
key:                  dice-0.1.1-H60z5Pag986CnHmdNz2OU6
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  3331d8a3f3e508455893d6578a8a0656
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-H60z5Pag986CnHmdNz2OU6
depends:
    base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    random-fu-0.3.0.1-KeRxVhFaQuPDNNGhS4noHx

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dice-0.1.1-60-x86_64.pkg.tar.zst: usr/share/haskell/register/dice.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-3ha4HgEXwxT6JtpFpc1uzd
key:                  dice-0.1.1-3ha4HgEXwxT6JtpFpc1uzd
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  b0763cb4cff29c4e10cca193744bc3b1
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-3ha4HgEXwxT6JtpFpc1uzd
depends:
    base-4.17.2.1 mtl-2.2.2 parsec-3.1.16.1
    random-1.2.1.2-23MFWqKwy7yBKL8EDiRtc8
    random-fu-0.3.0.1-9GAh519W4OUGqLaU9A4Sf7

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
